#!/usr/bin/env python
#----------------------------------------------------------------------
# Setup script for the BSDDB3 package

import sys, os
from distutils.core     import setup, Extension
from distutils.dep_util import newer

VERSION = "3.0b1"

#----------------------------------------------------------------------

debug = '--debug' in sys.argv or '-g' in sys.argv
if os.name == 'posix':
    # if yours is someplace else then edit this variable
    BERKELEYDB_DIR='/usr/local/BerkeleyDB.3.1'

    # figure it all out from the setting above
    incdir = os.path.join(BERKELEYDB_DIR, 'include')
    libdir = os.path.join(BERKELEYDB_DIR, 'lib')
    libname = 'db'
    utils = []


elif os.name == 'nt':
    # The default build of Berkeley DB for windows just leaves everything
    # in the build dirs in the db source tree.  That means that we either
    # have to hunt around to find it, or we make the builder specify
    # everything here.  Compounding the problem is version numbers in default
    # path names, and different library names for debug/release or dll/static.
    #
    # So to make things easier, I'm just going to exepect that the DB stuff
    # has been moved to the ./db directory.  There's an updatedb.bat file to
    # help.
    incdir = 'db/include'
    libdir = 'db/lib'
    if debug:
        libname = 'libdb31sd'     # Debug, static
    else:
        libname = 'libdb31s'      # Release, static
    utils = [("bsddb3/utils",
              ["db/bin/db_archive.exe",
               "db/bin/db_checkpoint.exe",
               "db/bin/db_deadlock.exe",
               "db/bin/db_dump.exe",
               "db/bin/db_load.exe",
               "db/bin/db_printlog.exe",
               "db/bin/db_recover.exe",
               "db/bin/db_stat.exe",
               "db/bin/db_upgrade.exe",
               "db/bin/db_verify.exe",
               "db/bin/libdb31.dll",
               ])]


# Update the version .h file if this file is newer
if newer('setup.py', 'src/version.h'):
    open('src/version.h', 'w').write('#define PY_BSDDB_VERSION "%s"\n' % VERSION)


# do the actuall build, install, whatever...
setup(name = 'bsddb3',
      version = VERSION,
      description = 'Python interface for BerkeleyDB 3.1.x',
      long_description = """\
This module provides a nearly complete wrapping
of the Sleepycat C API for the Database
Environment, Database, Cursor, and Transaction
objects, and each of these is exposed as a Python
Type in the bsddb3.db module.  The databse objects
can use various access methods: btree, hash, recno,
and queue.  For the first time all of these are
fully supported in the Python wrappers.  Please see
the documents in the docs directory of the source
distribution or at the website for more details on
the types and methods provided.""",

      author = 'Robin Dunn',
      author_email = 'robin@alldunn.com',
      url = 'http://PyBSDDB.sourceforge.net',

      packages = ['bsddb3'],
      ext_modules = [Extension('bsddb3._db',
                               include_dirs = [ incdir ],
                               library_dirs = [ libdir ],
                               libraries = [ libname ],
                               sources = ['src/_db.c']
                               )],
      data_files = utils,
      )









